@@ -18,10 +18,11 @@
 #include <fcitx-utils/eventdispatcher.h>
 #include <fcitx-utils/handlertable_details.h>
 #include <fcitx-utils/i18n.h>
+#include <fcitx-utils/key.h>
 #include <fcitx-utils/library.h>
 #include <fcitx-utils/log.h>
 #include <fcitx-utils/misc.h>
-#include <fcitx-utils/standardpath.h>
+#include <fcitx-utils/standardpaths.h>
 #include <fcitx-utils/stringutils.h>
 #include <fcitx/action.h>
 #include <fcitx/addoninstance.h>
@@ -99,21 +100,12 @@ FCITX_CONFIGURATION(
         this, "UserDataDir", _("User data dir"),
         stringutils::concat(
             "xdg-open \"",
-            stringutils::replaceAll(
-                stringutils::joinPath(StandardPath::global().userDirectory(
-                                          StandardPath::Type::PkgData),
-                                      "rime"),
-                "\"", "\"\"\""),
+            stringutils::replaceAll((StandardPaths::global().userDirectory(
+                                         StandardPathsType::PkgData) /
+                                     "rime")
+                                        .string(),
+                                    "\"", "\"\"\""),
             "\"")};
-#ifdef FCITX_RIME_LOAD_PLUGIN
-    Option<bool> autoloadPlugins{this, "AutoloadPlugins",
-                                 _("Load available plugins automatically"),
-                                 false};
-    Option<std::vector<std::string>> plugins{this, "Plugins", _("Plugins"),
-                                             std::vector<std::string>()};
-    Option<std::vector<std::string>> modules{this, "Modules", _("Modules"),
-                                             std::vector<std::string>()};
-#endif
     fcitx::Option<fcitx::KeyList> deploy{
         this, "Deploy", _("Deploy"),
         isApple() ? fcitx::KeyList{fcitx::Key("Control+Alt+grave")}
@@ -167,7 +159,7 @@ public:
     FCITX_ADDON_DEPENDENCY_LOADER(dbus, instance_->addonManager());
 #endif
 
-    void blockNotificationFor(uint64_t usec);
+    void allowNotification(std::string type = "");
     const auto &schemas() const { return schemas_; }
     const auto &optionActions() const { return optionActions_; };
 
@@ -177,7 +169,7 @@ private:
                                         const char *messageValue);
 
     void deploy();
-    void sync();
+    void sync(bool userTriggered);
     void updateSchemaMenu();
     void updateActionsForSchema(const std::string &schema);
     void notifyImmediately(RimeSessionId session, std::string_view type,
@@ -199,8 +191,9 @@ private:
     EventDispatcher eventDispatcher_;
     rime_api_t *api_;
     static bool firstRun_;
-    uint64_t blockNotificationBefore_ = 0;
-    uint64_t lastKeyEventTime_ = 0;
+    uint64_t silenceNotificationUntil_ = 0;
+    uint64_t allowNotificationUntil_ = 0;
+    std::string allowNotificationType_;
     FactoryFor<RimeState> factory_;
     bool needRefreshAppOption_ = false;
 
@@ -221,9 +214,6 @@ private:
                        std::list<std::unique_ptr<RimeOptionAction>>>
         optionActions_;
     Menu schemaMenu_;
-#ifdef FCITX_RIME_LOAD_PLUGIN
-    std::unordered_map<std::string, Library> pluginPool_;
-#endif
     std::unique_ptr<HandlerTableEntry<EventHandler>> globalConfigReloadHandle_;
 
 #ifndef FCITX_RIME_NO_DBUS
