@@ -6,8 +6,10 @@
  */
 #include "rimesession.h"
 #include "rimeengine.h"
+#include <cassert>
 #include <fcitx-utils/charutils.h>
 #include <fcitx-utils/log.h>
+#include <fcitx-utils/macros.h>
 #include <fcitx-utils/stringutils.h>
 #include <fcitx/inputcontext.h>
 #include <fcitx/inputcontextmanager.h>
@@ -18,7 +20,7 @@
 #include <tuple>
 #include <utility>
 
-namespace fcitx {
+namespace fcitx::rime {
 
 RimeSessionHolder::RimeSessionHolder(RimeSessionPool *pool,
                                      const std::string &program)
@@ -30,6 +32,8 @@ RimeSessionHolder::RimeSessionHolder(RimeSessionPool *pool,
         throw std::runtime_error("Failed to create session.");
     }
 
+    setProgramName(program);
+
     if (program.empty()) {
         return;
     }
@@ -53,6 +57,17 @@ RimeSessionHolder::~RimeSessionHolder() {
     }
 }
 
+void RimeSessionHolder::setProgramName(const std::string &program) {
+    // set_property will trigger property change notification, which is a little
+    // bit annoying, so don't set it, if the value is not changed.
+    if (program == currentProgram_) {
+        return;
+    }
+
+    currentProgram_ = program;
+    pool_->engine()->api()->set_property(id_, "client_app", program.data());
+}
+
 #if 0
 LogMessageBuilder &operator<<(LogMessageBuilder &log, const std::weak_ptr<RimeSessionHolder> &session) {
     auto sessionPtr = session.lock();
@@ -133,4 +148,4 @@ void RimeSessionPool::unregisterSession(const std::string &key) {
     assert(count > 0);
 }
 
-} // namespace fcitx
+} // namespace fcitx::rime
